# Generated by Django 2.1.3 on 2018-12-04 21:47

from django.db import migrations, models
import literature_knowledgebase.models


class Migration(migrations.Migration):

    dependencies = [
        ('literature_knowledgebase', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='article',
            name='file',
            field=models.FileField(blank=True, null=True, upload_to=literature_knowledgebase.models.file_path),
        ),
    ]
